@@ -112,7 +112,7 @@
    (list "ADDOMIT" "AFTER" "AT" "BAN" "BANNER" "BEFORE" "CAL" "CLEAR"
          "CLEAR-OMIT-CONTEXT" "DEBUG" "DO" "DUMP" "DUMPVARS" "DURATION" "ELSE"
          "ENDIF" "ERRMSG" "EXIT" "EXPR" "FIRST" "FLUSH" "FOURTH" "FRENAME" "FROM" "FSET"
-         "FUNSET" "IF" "IFTRIG" "IN" "INC" "INCLUDE" "INCLUDECMD" "LAST"
+         "FUNSET" "IF" "IFTRIG" "IN" "INC" "INCLUDE" "INCLUDECMD" "INFO" "LAST"
          "LASTDAY" "LASTWORKDAY" "MAYBE" "MAYBE-UNCOMPUTABLE" "MSF" "MSG"
          "NOQUEUE" "OMIT" "OMITFUNC" "ONCE" "POP" "POP-OMIT-CONTEXT" "PRESERVE"
          "PRIORITY" "PS" "PSFILE" "PUSH" "PUSH-OMIT-CONTEXT" "REM" "RUN"
@@ -166,7 +166,7 @@
    (list "_" "abs" "access" "adawn" "adusk" "ampm" "ansicolor" "args" "asc"
          "baseyr" "char" "choose" "coerce" "columns" "current" "date"
          "datepart" "datetime" "dawn" "day" "daysinmon" "defined" "dosubst"
-         "dusk" "easterdate" "evaltrig" "filedate" "filedatetime" "filedir"
+         "dusk" "easterdate" "escape" "evaltrig" "filedate" "filedatetime" "filedir"
          "filename" "getenv" "hebdate" "hebday" "hebmon" "hebyear" "hour"
          "htmlescape" "htmlstriptags" "iif" "index" "isany" "isdst" "isleap"
          "isomitted" "language" "localtoutc" "lower" "max" "min" "minsfromutc"
@@ -177,7 +177,7 @@
          "slide" "soleq" "stdout" "strlen" "substr" "sunrise" "sunset" "time"
          "timepart" "timezone" "today" "trig" "trigback" "trigdate"
          "trigdatetime" "trigdelta" "trigduration" "trigeventduration"
-         "trigeventstart" "trigfrom" "trigger" "trigpriority" "trigrep"
+         "trigeventstart" "trigfrom" "trigger" "triginfo" "trigpriority" "trigrep"
          "trigscanfrom" "trigtags" "trigtime" "trigtimedelta" "trigtimerep"
          "triguntil" "trigvalid" "typeof" "tzconvert" "upper" "utctolocal"
          "value" "version" "weekno" "wkday" "wkdaynum" "year")
