@@ -61,6 +61,7 @@ typedef struct cal_entry {
     TimeTrig tt;
     int nonconst_expr;
     int if_depth;
+    TrigInfo *infos;
 } CalEntry;
 
 /* Line-drawing sequences */
@@ -387,7 +388,13 @@ void PrintJSONChar(char c) {
     case '\t': printf("\\t"); break;
     case '"':  printf("\\\""); break;
     case '\\': printf("\\\\"); break;
-    default: printf("%c", c);
+    default:
+        if ((c > 0 && c < 32) || c == 0x7f) {
+            printf("\\u%04x", (unsigned int) c);
+        } else {
+            printf("%c", c);
+        }
+        break;
     }
 }
 
@@ -402,7 +409,36 @@ void PrintJSONString(char const *s)
         case '\t': printf("\\t"); break;
         case '"':  printf("\\\""); break;
         case '\\': printf("\\\\"); break;
-        default: printf("%c", *s);
+        default:
+            if ((*s > 0 && *s < 32) || *s == 0x7f) {
+                printf("\\u%04x", (unsigned int) *s);
+            } else {
+                printf("%c", *s);
+            }
+            break;
+        }
+        s++;
+    }
+}
+
+void PrintJSONStringLC(char const *s)
+{
+    while (*s) {
+        switch(*s) {
+        case '\b': printf("\\b"); break;
+        case '\f': printf("\\f"); break;
+        case '\n': printf("\\n"); break;
+        case '\r': printf("\\r"); break;
+        case '\t': printf("\\t"); break;
+        case '"':  printf("\\\""); break;
+        case '\\': printf("\\\\"); break;
+        default:
+            if ((*s > 0 && *s < 32) || *s == 0x7f) {
+                printf("\\u%04x", (unsigned int) *s);
+            } else {
+                printf("%c", tolower(*s));
+            }
+            break;
         }
         s++;
     }
@@ -499,7 +535,7 @@ get_month_abbrev(char const *mon)
 {
     static char buf[80];
 #ifndef REM_USE_WCHAR
-    sprintf(buf, "%.3s", mon);
+    snprintf(buf, sizeof(buf), "%.3s", mon);
     return buf;
 #else
     char *s;
@@ -626,9 +662,9 @@ Colorize256(int r, int g, int b, int bg, int clamp)
         }
     }
     if (bg) {
-        sprintf(buf, "\x1B[48;5;%dm", best);
+        snprintf(buf, sizeof(buf), "\x1B[48;5;%dm", best);
     } else {
-        sprintf(buf, "\x1B[38;5;%dm", best);
+        snprintf(buf, sizeof(buf), "\x1B[38;5;%dm", best);
     }
     return buf;
 }
@@ -641,9 +677,9 @@ ColorizeTrue(int r, int g, int b, int bg, int clamp)
         ClampColor(&r, &g, &b);
     }
     if (bg) {
-        sprintf(buf, "\x1B[48;2;%d;%d;%dm", r, g, b);
+        snprintf(buf, sizeof(buf), "\x1B[48;2;%d;%d;%dm", r, g, b);
     } else {
-        sprintf(buf, "\x1B[38;2;%d;%d;%dm", r, g, b);
+        snprintf(buf, sizeof(buf), "\x1B[38;2;%d;%d;%dm", r, g, b);
     }
     return buf;
 }
@@ -1504,6 +1540,7 @@ static int WriteOneColLine(int col)
             free(e->raw_text);
             free(e->filename);
             if (e->wc_text) free(e->wc_text);
+            FreeTrigInfoChain(e->infos);
             free(e);
             return 1;
         }
@@ -1590,6 +1627,7 @@ static int WriteOneColLine(int col)
             free(e->raw_text);
             free(e->filename);
             if (e->wc_text) free(e->wc_text);
+            FreeTrigInfoChain(e->infos);
             free(e);
         } else {
             e->wc_pos = ws;
@@ -1611,6 +1649,7 @@ static int WriteOneColLine(int col)
             if (e->wc_text) free(e->wc_text);
 #endif
             free(e->raw_text);
+            FreeTrigInfoChain(e->infos);
             free(e);
             return 1;
         }
@@ -1673,6 +1712,7 @@ static int WriteOneColLine(int col)
             if (e->wc_text) free(e->wc_text);
 #endif
             free(e->raw_text);
+            FreeTrigInfoChain(e->infos);
             free(e);
         } else {
             e->pos = s;
@@ -1812,7 +1852,7 @@ static void WriteCalHeader(void)
     int y, m, d;
 
     FromDSE(DSEToday, &y, &m, &d);
-    sprintf(buf, "%s %d", get_month_name(m), y);
+    snprintf(buf, sizeof(buf), "%s %d", get_month_name(m), y);
 
     WriteTopCalLine();
 
@@ -2016,7 +2056,7 @@ static int DoCalRem(ParsePtr p, int col)
         trig.typ == MSF_TYPE) {
         if (PsCal && is_color) {
             char cbuf[24];
-            sprintf(cbuf, "%d %d %d ", col_r, col_g, col_b);
+            snprintf(cbuf, sizeof(cbuf), "%d %d %d ", col_r, col_g, col_b);
             DBufPuts(&pre_buf, cbuf);
             strcpy(trig.passthru, "COLOR");
             /* Don't change trig.typ or next if() will trigger! */
@@ -2149,7 +2189,7 @@ static int DoCalRem(ParsePtr p, int col)
         if (trig.typ != PASSTHRU_TYPE &&
             UserFuncExists("calprefix")==1) {
             char evalBuf[64];
-            sprintf(evalBuf, "calprefix(%d)", trig.priority);
+            snprintf(evalBuf, sizeof(evalBuf), "calprefix(%d)", trig.priority);
             s2 = evalBuf;
             r = EvalExpr(&s2, &v, NULL);
             if (!r) {
@@ -2192,7 +2232,7 @@ static int DoCalRem(ParsePtr p, int col)
         if (trig.typ != PASSTHRU_TYPE &&
             UserFuncExists("calsuffix")==1) {
             char evalBuf[64];
-            sprintf(evalBuf, "calsuffix(%d)", trig.priority);
+            snprintf(evalBuf, sizeof(evalBuf), "calsuffix(%d)", trig.priority);
             s2 = evalBuf;
             r = EvalExpr(&s2, &v, NULL);
             if (!r) {
@@ -2232,6 +2272,7 @@ static int DoCalRem(ParsePtr p, int col)
             FreeTrig(&trig);
             return E_NO_MEM;
         }
+        e->infos = NULL;
         e->nonconst_expr = nonconst_expr;
         e->if_depth = NumIfs;
         e->trig = trig;
@@ -2252,6 +2293,7 @@ static int DoCalRem(ParsePtr p, int col)
         if (!e->text || !e->raw_text) {
             if (e->text) free(e->text);
             if (e->raw_text) free(e->raw_text);
+            FreeTrigInfoChain(e->infos);
             free(e);
             FreeTrig(&trig);
             return E_NO_MEM;
@@ -2265,12 +2307,17 @@ static int DoCalRem(ParsePtr p, int col)
             AppendTag(&(e->tags), SynthesizeTag());
         }
 
+        /* Take over any TrigInfo! */
+        e->infos = trig.infos;
+        trig.infos = NULL;
+
         /* Don't need tags any more */
         FreeTrig(&trig);
         e->duration = tim.duration;
         e->priority = trig.priority;
         e->filename = StrDup(FileName);
         if(!e->filename) {
+            FreeTrigInfoChain(e->infos);
             if (e->text) free(e->text);
             if (e->raw_text) free(e->raw_text);
 #ifdef REM_USE_WCHAR
@@ -2342,6 +2389,41 @@ void WriteJSONTimeTrigger(TimeTrig const *tt)
     }
 }
 
+void
+WriteJSONInfoChain(TrigInfo *ti)
+{
+    printf("\"info\":{");
+    while (ti) {
+        /* Skanky... */
+        char *colon = (char *) strchr(ti->info, ':');
+        char const *value;
+        if (!colon) {
+            /* Should be impossible... */
+            ti = ti->next;
+            continue;
+        }
+        /* Terminate the string at the colon */
+        *colon = 0;
+
+        value = colon+1;
+        while(*value && isspace(*value)) {
+            value++;
+        }
+        printf("\"");
+        PrintJSONStringLC(ti->info);
+        printf("\":\"");
+        PrintJSONString(value);
+        printf("\"");
+
+        /* Restore the value of the colon */
+        *colon = ':';
+        if (ti->next) {
+            printf(",");
+        }
+        ti = ti->next;
+    }
+    printf("},");
+}
 void WriteJSONTrigger(Trigger const *t, int include_tags, int today)
 {
     /* wd is an array of days from 0=monday to 6=sunday.
@@ -2433,6 +2515,9 @@ void WriteJSONTrigger(Trigger const *t, int include_tags, int today)
         PrintJSONKeyPairInt("addomit", 1);
     }
     if (include_tags) {
+        if (t->infos) {
+            WriteJSONInfoChain(t->infos);
+        }
         PrintJSONKeyPairString("tags", DBufValue(&(t->tags)));
     }
 }
@@ -2446,6 +2531,9 @@ static void WriteSimpleEntryProtocol2(CalEntry *e, int today)
     }
     PrintJSONKeyPairString("passthru", e->passthru);
     PrintJSONKeyPairString("tags", DBufValue(&(e->tags)));
+    if (e->infos) {
+        WriteJSONInfoChain(e->infos);
+    }
     if (e->duration != NO_TIME) {
         PrintJSONKeyPairInt("duration", e->duration);
     }
@@ -2576,6 +2664,7 @@ static void WriteSimpleEntries(int col, int dse)
         free(e->text);
         free(e->raw_text);
         free(e->filename);
+        FreeTrigInfoChain(e->infos);
 #ifdef REM_USE_WCHAR
         if (e->wc_text) free(e->wc_text);
 #endif
@@ -2736,7 +2825,7 @@ CalendarTime(int tim, int duration)
     else              hh2 = h2;
 
     if (days) {
-        sprintf(daybuf, "+%d", days);
+        snprintf(daybuf, sizeof(daybuf), "+%d", days);
     } else {
         daybuf[0] = 0;
     }
@@ -2759,12 +2848,12 @@ CalendarTime(int tim, int duration)
 
     switch(ScFormat) {
     case SC_AMPM:
-        sprintf(buf, "%d%c%02d%s-%d%c%02d%s%s ",
+        snprintf(buf, sizeof(buf), "%d%c%02d%s-%d%c%02d%s%s ",
                 hh, TimeSep, min, ampm1, hh2, TimeSep, min2, ampm2, daybuf);
         break;
 
     case SC_MIL:
-        sprintf(buf, "%02d%c%02d-%02d%c%02d%s ",
+        snprintf(buf, sizeof(buf), "%02d%c%02d-%02d%c%02d%s ",
                 h, TimeSep, min, h2, TimeSep, min2, daybuf);
         break;
     }
@@ -2782,7 +2871,7 @@ CalendarTime(int tim, int duration)
 /***************************************************************/
 char const *SimpleTime(int tim)
 {
-    static char buf[32];
+    static char buf[128];
     int h, min, hh;
 
     buf[0] = 0;
@@ -2796,7 +2885,7 @@ char const *SimpleTime(int tim)
             if (h == 0) hh=12;
             else if (h > 12) hh=h-12;
             else hh=h;
-            sprintf(buf, "%d%c%02d%s ", hh, TimeSep, min, (h>=12) ? tr("pm") : tr("am"));
+            snprintf(buf, sizeof(buf), "%d%c%02d%.64s ", hh, TimeSep, min, (h>=12) ? tr("pm") : tr("am"));
         }
         break;
 
@@ -2804,7 +2893,7 @@ char const *SimpleTime(int tim)
         if (tim != NO_TIME) {
             h = tim / 60;
             min = tim % 60;
-            sprintf(buf, "%02d%c%02d ", h, TimeSep, min);
+            snprintf(buf, sizeof(buf), "%02d%c%02d ", h, TimeSep, min);
         }
         break;
     }
@@ -2856,7 +2945,7 @@ char const *SynthesizeTag(void)
     MD5Init(&ctx);
     MD5Update(&ctx, (unsigned char *) CurLine, strlen(CurLine));
     MD5Final(buf, &ctx);
-    sprintf(out, "__syn__%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
+    snprintf(out, sizeof(out), "__syn__%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
             (unsigned int) buf[0], (unsigned int) buf[1],
             (unsigned int) buf[2], (unsigned int) buf[3],
             (unsigned int) buf[4], (unsigned int) buf[5],
