@@ -40,7 +40,7 @@ check_subst_args(UserFunc *f, int n)
     if (f->nargs == n) {
         return 1;
     }
-    Wprint("Function `%s' defined at %s:%d should take %d argument%s, but actually takes %d",
+    Wprint(tr("Function `%s' defined at %s:%d should take %d argument%s, but actually takes %d"),
            f->name, f->filename, f->lineno, n, (n == 1 ? "" : "s"), f->nargs);
     return 0;
 }
@@ -215,6 +215,33 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
         if (!c) {
             break;
         }
+        if (c == '<') {
+            DynamicBuffer header;
+            char const *val;
+            DBufInit(&header);
+
+            while(1) {
+                c = ParseChar(p, &err, 0);
+                if (err) {
+                    DBufFree(&header);
+                    return err;
+                }
+                if (!c || c == '>') {
+                    break;
+                }
+                DBufPutc(&header, c);
+            }
+            if (!c) {
+                Wprint(tr("Warning: Unterminated %%<...> substitution sequence"));
+            }
+            err = OK;
+            val = FindTrigInfo(t, DBufValue(&header));
+            DBufFree(&header);
+            if (val) {
+                SHIP_OUT(val);
+            }
+            continue;
+        }
         if (c == '(') {
             DynamicBuffer orig;
             DynamicBuffer translated;
@@ -232,7 +259,7 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
                 DBufPutc(&orig, c);
             }
             if (!c) {
-                Wprint("Warning: Unterminated %%(...) substitution sequence");
+                Wprint(tr("Warning: Unterminated %%(...) substitution sequence"));
             }
             err = OK;
             if (GetTranslatedStringTryingVariants(DBufValue(&orig), &translated)) {
@@ -240,6 +267,9 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
             } else {
                 err = DBufPuts(dbuf, DBufValue(&orig));
             }
+            if (DebugFlag & DB_TRANSLATE) {
+                TranslationTemplate(DBufValue(&orig));
+            }
             DBufFree(&orig);
             DBufFree(&translated);
             if (err) return err;
@@ -275,11 +305,11 @@ int DoSubst(ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse,
                 }
             }
             if (!c) {
-                Wprint("Warning: Unterminated %%{...} substitution sequence");
+                Wprint(tr("Warning: Unterminated %%{...} substitution sequence"));
             }
             func = FindUserFunc(s);
             if (!func) {
-                Wprint("No substition function `%s' defined", s);
+                Wprint(tr("No substition function `%s' defined"), s);
                 continue;
             }
 
@@ -752,6 +782,8 @@ int DoSubstFromString(char const *source, DynamicBuffer *dbuf,
     if (tim == NO_TIME) tim=MinutesPastMidnight(0);
     CreateParser(source, &tempP);
     tempP.allownested = 0;
+    tempTrig.infos = NULL;
+    DBufInit(&tempTrig.tags);
     tempTrig.typ = MSG_TYPE;
     tempTime.ttime = tim;
 
