@@ -299,7 +299,7 @@ json_value * json_parse_ex (json_settings * settings,
          if (flags & flag_string)
          {
             if (!b)
-            {  sprintf (error, "Unexpected EOF in string (at %u:%u)", line_and_col);
+            {  snprintf (error, sizeof(error), "Unexpected EOF in string (at %u:%u)", line_and_col);
                goto e_failed;
             }
 
@@ -325,7 +325,7 @@ json_value * json_parse_ex (json_settings * settings,
                         (uc_b3 = hex_value (*++ state.ptr)) == 0xFF ||
                         (uc_b4 = hex_value (*++ state.ptr)) == 0xFF)
                     {
-                        sprintf (error, "Invalid character value `%c` (at %u:%u)", b, line_and_col);
+                        snprintf (error, sizeof(error), "Invalid character value `%c` (at %u:%u)", b, line_and_col);
                         goto e_failed;
                     }
 
@@ -342,7 +342,7 @@ json_value * json_parse_ex (json_settings * settings,
                             (uc_b3 = hex_value (*++ state.ptr)) == 0xFF ||
                             (uc_b4 = hex_value (*++ state.ptr)) == 0xFF)
                         {
-                            sprintf (error, "Invalid character value `%c` (at %u:%u)", b, line_and_col);
+                            snprintf (error, sizeof(error), "Invalid character value `%c` (at %u:%u)", b, line_and_col);
                             goto e_failed;
                         }
 
@@ -472,7 +472,7 @@ json_value * json_parse_ex (json_settings * settings,
                if (flags & flag_block_comment)
                {
                   if (!b)
-                  {  sprintf (error, "%u:%u: Unexpected EOF in block comment", line_and_col);
+                  {  snprintf (error, sizeof(error), "%u:%u: Unexpected EOF in block comment", line_and_col);
                      goto e_failed;
                   }
 
@@ -488,12 +488,12 @@ json_value * json_parse_ex (json_settings * settings,
             else if (b == '/')
             {
                if (! (flags & (flag_seek_value | flag_done)) && top->type != json_object)
-               {  sprintf (error, "%u:%u: Comment not allowed here", line_and_col);
+               {  snprintf (error, sizeof(error), "%u:%u: Comment not allowed here", line_and_col);
                   goto e_failed;
                }
 
                if (++ state.ptr == end)
-               {  sprintf (error, "%u:%u: EOF unexpected", line_and_col);
+               {  snprintf (error, sizeof(error), "%u:%u: EOF unexpected", line_and_col);
                   goto e_failed;
                }
 
@@ -508,7 +508,7 @@ json_value * json_parse_ex (json_settings * settings,
                      continue;
 
                   default:
-                     sprintf (error, "%u:%u: Unexpected `%c` in comment opening sequence", line_and_col, b);
+                     snprintf (error, sizeof(error), "%u:%u: Unexpected `%c` in comment opening sequence", line_and_col, b);
                      goto e_failed;
                };
             }
@@ -526,7 +526,7 @@ json_value * json_parse_ex (json_settings * settings,
 
                default:
 
-                  sprintf (error, "%u:%u: Trailing garbage: `%c`",
+                  snprintf (error, sizeof(error), "%u:%u: Trailing garbage: `%c`",
                            state.cur_line, state.cur_col, b);
 
                   goto e_failed;
@@ -545,7 +545,7 @@ json_value * json_parse_ex (json_settings * settings,
                   if (top && top->type == json_array)
                      flags = (flags & ~ (flag_need_comma | flag_seek_value)) | flag_next;
                   else
-                  {  sprintf (error, "%u:%u: Unexpected ]", line_and_col);
+                  {  snprintf (error, sizeof(error), "%u:%u: Unexpected ]", line_and_col);
                      goto e_failed;
                   }
 
@@ -561,7 +561,7 @@ json_value * json_parse_ex (json_settings * settings,
                      }
                      else
                      {
-                        sprintf (error, "%u:%u: Expected , before %c",
+                        snprintf (error, sizeof(error), "%u:%u: Expected , before %c",
                                  state.cur_line, state.cur_col, b);
 
                         goto e_failed;
@@ -576,7 +576,7 @@ json_value * json_parse_ex (json_settings * settings,
                      }
                      else
                      {
-                        sprintf (error, "%u:%u: Expected : before %c",
+                        snprintf (error, sizeof(error), "%u:%u: Expected : before %c",
                                  state.cur_line, state.cur_col, b);
 
                         goto e_failed;
@@ -702,7 +702,7 @@ json_value * json_parse_ex (json_settings * settings,
                            continue;
                         }
                         else
-                        {  sprintf (error, "%u:%u: Unexpected %c when seeking value", line_and_col, b);
+                        {  snprintf (error, sizeof(error), "%u:%u: Unexpected %c when seeking value", line_and_col, b);
                            goto e_failed;
                         }
                   };
@@ -722,7 +722,7 @@ json_value * json_parse_ex (json_settings * settings,
                   case '"':
 
                      if (flags & flag_need_comma)
-                     {  sprintf (error, "%u:%u: Expected , before \"", line_and_col);
+                     {  snprintf (error, sizeof(error), "%u:%u: Expected , before \"", line_and_col);
                         goto e_failed;
                      }
 
@@ -747,7 +747,7 @@ json_value * json_parse_ex (json_settings * settings,
                      }
                      /* FALLTHROUGH */
                   default:
-                     sprintf (error, "%u:%u: Unexpected `%c` in object", line_and_col, b);
+                     snprintf (error, sizeof(error), "%u:%u: Unexpected `%c` in object", line_and_col, b);
                      goto e_failed;
                };
 
@@ -765,7 +765,7 @@ json_value * json_parse_ex (json_settings * settings,
                      if (! (flags & flag_num_e))
                      {
                         if (flags & flag_num_zero)
-                        {  sprintf (error, "%u:%u: Unexpected `0` before `%c`", line_and_col, b);
+                        {  snprintf (error, sizeof(error), "%u:%u: Unexpected `0` before `%c`", line_and_col, b);
                            goto e_failed;
                         }
 
@@ -814,7 +814,7 @@ json_value * json_parse_ex (json_settings * settings,
                else if (b == '.' && top->type == json_integer)
                {
                   if (!num_digits)
-                  {  sprintf (error, "%u:%u: Expected digit before `.`", line_and_col);
+                  {  snprintf (error, sizeof(error), "%u:%u: Expected digit before `.`", line_and_col);
                      goto e_failed;
                   }
 
@@ -831,7 +831,7 @@ json_value * json_parse_ex (json_settings * settings,
                   if (top->type == json_double)
                   {
                      if (!num_digits)
-                     {  sprintf (error, "%u:%u: Expected digit after `.`", line_and_col);
+                     {  snprintf (error, sizeof(error), "%u:%u: Expected digit after `.`", line_and_col);
                         goto e_failed;
                      }
 
@@ -857,7 +857,7 @@ json_value * json_parse_ex (json_settings * settings,
                else
                {
                   if (!num_digits)
-                  {  sprintf (error, "%u:%u: Expected digit after `e`", line_and_col);
+                  {  snprintf (error, sizeof(error), "%u:%u: Expected digit after `e`", line_and_col);
                      goto e_failed;
                   }
 
@@ -942,7 +942,7 @@ json_value * json_parse_ex (json_settings * settings,
 
 e_unknown_value:
 
-   sprintf (error, "%u:%u: Unknown value", line_and_col);
+   snprintf (error, sizeof(error), "%u:%u: Unknown value", line_and_col);
    goto e_failed;
 
 e_alloc_failure:
@@ -952,7 +952,7 @@ e_alloc_failure:
 
 e_overflow:
 
-   sprintf (error, "%u:%u: Too long (caught overflow)", line_and_col);
+   snprintf (error, sizeof(error), "%u:%u: Too long (caught overflow)", line_and_col);
    goto e_failed;
 
 e_failed:
