@@ -145,6 +145,7 @@ int main(int argc, char *argv[])
     }
 
     DBufInit(&(LastTrigger.tags));
+    LastTrigger.infos = NULL;
     ClearLastTriggers();
 
     atexit(exitfunc);
@@ -179,6 +180,7 @@ int main(int argc, char *argv[])
                 printf("%s\n", GetErr(E_NOREMINDERS));
             } else if (!Daemon && !NextMode && !NumTriggered) {
                 printf(GetErr(M_QUEUED), NumQueued);
+                printf("\n");
             }
         }
 
@@ -373,7 +375,7 @@ static void DoReminders(void)
 
             default:
                 if (!SuppressImplicitRemWarnings) {
-                    Wprint("Unrecognized command; interpreting as REM");
+                    Wprint(tr("Unrecognized command; interpreting as REM"));
                     WarnedAboutImplicit = 1;
                 }
                 DestroyParser(&p);
@@ -629,7 +631,9 @@ int ParseTokenOrQuotedString(ParsePtr p, DynamicBuffer *dbuf)
 /***************************************************************/
 int ParseQuotedString(ParsePtr p, DynamicBuffer *dbuf)
 {
-    int c, err;
+    int c, err, c2;
+    char hexbuf[3];
+
     DBufFree(dbuf);
     c = ParseNonSpaceChar(p, &err, 0);
     if (err) return err;
@@ -673,6 +677,34 @@ int ParseQuotedString(ParsePtr p, DynamicBuffer *dbuf)
             case 'v':
                 err = DBufPutc(dbuf, '\v');
                 break;
+            case 'x':
+                /* \x Followed by one or two hex digits */
+                c2 = ParseChar(p, &err, 1);
+                if (err) break;
+                if (!isxdigit(c2)) {
+                    err = DBufPutc(dbuf, c);
+                    break;
+                }
+                hexbuf[0] = c2;
+                hexbuf[1] = 0;
+                c2 = ParseChar(p, &err, 0);
+                if (err) break;
+                c2 = ParseChar(p, &err, 1);
+                if (err) break;
+                if (isxdigit(c2)) {
+                    hexbuf[1] = c2;
+                    hexbuf[2] = 0;
+                    c2 = ParseChar(p, &err, 0);
+                    if (err) break;
+                }
+                c2 = (int) strtol(hexbuf, NULL, 16);
+                if (!c2) {
+                    Eprint(tr("\\x00 is not a valid escape sequence"));
+                    err = E_PARSE_ERR;
+                } else {
+                    err = DBufPutc(dbuf, c2);
+                }
+                break;
             default:
                 err = DBufPutc(dbuf, c);
             }
@@ -1009,6 +1041,11 @@ int SystemTime(int realtime)
 
     if (!realtime && (SysTime != -1)) return SysTime;
 
+    if (TestMode) {
+        /* Pretend it's 7:00PM in test mode */
+        return 19 * 3600;
+    }
+
     now = time(NULL);
     t = localtime(&now);
     return t->tm_hour * 3600L + t->tm_min * 60L +
@@ -1042,6 +1079,14 @@ int SystemDate(int *y, int *m, int *d)
     time_t now;
     struct tm *t;
 
+    /* In test mode, always return 6 January 2025 */
+    if (TestMode) {
+        *y = 2025;
+        *m = 0;
+        *d = 6;
+        return 12789; /* 2025-01-06 */
+    }
+
     now = time(NULL);
     t = localtime(&now);
 
@@ -1267,6 +1312,12 @@ int DoDebug(ParsePtr p)
             else     DebugFlag &= ~DB_ECHO_LINE;
             break;
 
+        case 'q':
+        case 'Q':
+            if (val) DebugFlag |=  DB_TRANSLATE;
+            else     DebugFlag &= ~DB_TRANSLATE;
+            break;
+
         case 's':
         case 'S':
             if (val) DebugFlag |=  DB_PARSE_EXPR;
@@ -1308,6 +1359,9 @@ int DoDebug(ParsePtr p)
             if (val) DebugFlag |= DB_TRACE_FILES;
             else     DebugFlag &= ~DB_TRACE_FILES;
             break;
+        default:
+            Wprint(GetErr(M_BAD_DB_FLAG), ch);
+            break;
         }
     }
 }
@@ -1892,6 +1946,10 @@ void
 FreeTrig(Trigger *t)
 {
     DBufFree(&(t->tags));
+    if (t->infos) {
+        FreeTrigInfoChain(t->infos);
+    }
+    t->infos = NULL;
 }
 
 void
@@ -1917,8 +1975,7 @@ ClearLastTriggers(void)
     LastTrigger.warn[0] = 0;
     LastTrigger.omitfunc[0] = 0;
     LastTrigger.passthru[0] = 0;
-    DBufFree(&(LastTrigger.tags));
-
+    FreeTrig(&LastTrigger);
     LastTimeTrig.ttime = NO_TIME;
     LastTimeTrig.delta = NO_DELTA;
     LastTimeTrig.rep   = NO_REP;
@@ -1938,10 +1995,19 @@ SaveAllTriggerInfo(Trigger const *t, TimeTrig const *tt, int trigdate, int trigt
 void
 SaveLastTrigger(Trigger const *t)
 {
-    DBufFree(&(LastTrigger.tags));
+    FreeTrig(&LastTrigger);
     memcpy(&LastTrigger, t, sizeof(LastTrigger));
+
+    /* DON'T hang on to the invalid info chain! */
+    LastTrigger.infos = NULL;
     DBufInit(&(LastTrigger.tags));
+
     DBufPuts(&(LastTrigger.tags), DBufValue(&(t->tags)));
+    TrigInfo *cur = t->infos;
+    while(cur) {
+        AppendTrigInfo(&LastTrigger, cur->info);
+        cur = cur->next;
+    }
 }
 
 void
@@ -2034,7 +2100,7 @@ static int GetOnceDateFromFile(void)
     /* Save today to file */
     fp = fopen(OnceFile, "w");
     if (!fp) {
-        Wprint("Warning: Unable to save ONCE timestamp to %s: %s",
+        Wprint(tr("Warning: Unable to save ONCE timestamp to %s: %s"),
                OnceFile, strerror(errno));
         return once_date;
     }
@@ -2055,25 +2121,9 @@ int GetOnceDate(void)
     return OnceDate;
 }
 
-static void
-get_printf_escapes(char const *str, DynamicBuffer *out)
-{
-    char const *s = str;
-    while(*s) {
-        if (*s == '%' && *(s+1) != 0) {
-            s++;
-            DBufPutc(out, *s);
-        }
-        s++;
-    }
-}
-
 char const *GetErr(int r)
 {
     char const *msg;
-    DynamicBuffer origEscapes;
-    DynamicBuffer translatedEscapes;
-    int dangerous;
 
     if (r < 0 || r >= NumErrs) {
         r = E_SWERR;
@@ -2084,23 +2134,5 @@ char const *GetErr(int r)
         return ErrMsg[r];
     }
 
-    /* We need to make sure both the original and translated version
-       have the *SAME* printf-style escapes to avoid a malicious
-       translation file doing a format-string attack */
-    DBufInit(&origEscapes);
-    DBufInit(&translatedEscapes);
-
-    get_printf_escapes(ErrMsg[r], &origEscapes);
-    get_printf_escapes(msg, &translatedEscapes);
-
-    dangerous = strcmp(DBufValue(&origEscapes), DBufValue(&translatedEscapes));
-
-    DBufFree(&origEscapes);
-    DBufFree(&translatedEscapes);
-
-    if (dangerous) {
-        return ErrMsg[r];
-    } else {
-        return msg;
-    }
+    return msg;
 }
