@@ -92,7 +92,7 @@ int DestroyOmitContexts(int print_unmatched)
 
     while (c) {
         if (print_unmatched) {
-            Wprint("Unmatched PUSH-OMIT-CONTEXT at %s(%d)",
+            Wprint(tr("Unmatched PUSH-OMIT-CONTEXT at %s(%d)"),
                    c->filename, c->lineno);
         }
         num++;
@@ -186,7 +186,7 @@ int PopOmitContext(ParsePtr p)
     SavedOmitContexts = c->next;
 
     if (c->filename && FileName && strcmp(c->filename, FileName)) {
-        Wprint("POP-OMIT-CONTEXT at %s:%d matches PUSH-OMIT-CONTEXT in different file: %s:%d", FileName, LineNo, c->filename, c->lineno);
+        Wprint(tr("POP-OMIT-CONTEXT at %s:%d matches PUSH-OMIT-CONTEXT in different file: %s:%d"), FileName, LineNo, c->filename, c->lineno);
     }
     /* Free memory used by the saved context */
     if (c->partsave) free(c->partsave);
@@ -218,7 +218,7 @@ int IsOmitted(int dse, int localomit, char const *omitfunc, int *omit)
         Value v;
 
         FromDSE(dse, &y, &m, &d);
-        sprintf(expr, "%s('%04d-%02d-%02d')",
+        snprintf(expr, sizeof(expr), "%s('%04d-%02d-%02d')",
                 omitfunc, y, m+1, d);
         s = expr;
         r = EvalExpr(&s, &v, NULL);
@@ -388,6 +388,7 @@ int DoOmit(ParsePtr p)
         case T_RemType:
         case T_Priority:
         case T_Tag:
+        case T_Info:
         case T_Duration:
             DBufFree(&buf);
             parsing = 0;
@@ -395,7 +396,7 @@ int DoOmit(ParsePtr p)
 
         default:
             if (tok.type == T_Until) {
-                Eprint("OMIT: UNTIL not allowed; did you mean THROUGH?");
+                Eprint(tr("OMIT: UNTIL not allowed; did you mean THROUGH?"));
             } else if (tok.type == T_Illegal && tok.val < 0) {
                 Eprint("%s: `%s'", GetErr(-tok.val), DBufValue(&buf));
             } else {
@@ -415,7 +416,7 @@ int DoOmit(ParsePtr p)
             return E_2MANY_LOCALOMIT;
         }
         WeekdayOmits |= wd;
-        if (tok.type == T_Tag || tok.type == T_Duration || tok.type == T_RemType || tok.type == T_Priority) return E_PARSE_AS_REM;
+        if (tok.type == T_Tag || tok.type == T_Info || tok.type == T_Duration || tok.type == T_RemType || tok.type == T_Priority) return E_PARSE_AS_REM;
         return OK;
     }
 
@@ -465,7 +466,7 @@ int DoOmit(ParsePtr p)
                 InsertIntoSortedArray(PartialOmitArray, NumPartialOmits, syndrome);
                 NumPartialOmits++;
                 if (NumPartialOmits == 366) {
-                    Wprint("You have OMITted everything!  The space-time continuum is at risk.");
+                    Wprint(tr("You have OMITted everything!  The space-time continuum is at risk."));
                 }
             }
             if (mc == m[1] && dc == d[1]) {
@@ -487,7 +488,7 @@ int DoOmit(ParsePtr p)
         start = DSE(y[0], m[0], d[0]);
         end   = DSE(y[1], m[1], d[1]);
         if (end < start) {
-            Eprint("Error: THROUGH date earlier than start date");
+            Eprint(tr("Error: THROUGH date earlier than start date"));
             return E_BAD_DATE;
         }
 
@@ -500,7 +501,7 @@ int DoOmit(ParsePtr p)
         }
     }
 
-    if (tok.type == T_Tag || tok.type == T_Duration || tok.type == T_RemType || tok.type == T_Priority) return E_PARSE_AS_REM;
+    if (tok.type == T_Tag || tok.type == T_Info || tok.type == T_Duration || tok.type == T_RemType || tok.type == T_Priority) return E_PARSE_AS_REM;
     return OK;
 
 }
