@@ -273,3 +273,14 @@ int GetTranslatedStringTryingVariants(char const *orig, DynamicBuffer *out);
 char const *GetErr(int r);
 char const *tr(char const *s);
 void print_escaped_string(FILE *fp, char const *s);
+void print_escaped_string_helper(FILE *fp, char const *s, int esc_for_remind, int json);
+void GenerateSysvarTranslationTemplates(void);
+void TranslationTemplate(char const *msg);
+TrigInfo *NewTrigInfo(char const *i);
+void FreeTrigInfo(TrigInfo *ti);
+void FreeTrigInfoChain(TrigInfo *ti);
+int AppendTrigInfo(Trigger *t, char const *info);
+int TrigInfoHeadersAreTheSame(char const *i1, char const *i2);
+int TrigInfoIsValid(char const *info);
+char const *FindTrigInfo(Trigger *t, char const *header);
+void WriteJSONInfoChain(TrigInfo *ti);
