@@ -12,8 +12,9 @@
 
 #include "config.h"
 #include <stdio.h>
-
 #include <stdlib.h>
+#include <string.h>
+
 #include "types.h"
 #include "protos.h"
 #include "globals.h"
@@ -668,3 +669,151 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
     return -1;
 }
 
+/***************************************************************/
+/*                                                             */
+/*  NewTrigInfo                                                */
+/*                                                             */
+/*  Create a new TrigInfo object with the specified contents.  */
+/*  Returns NULL if memory allocation fails.                   */
+/*                                                             */
+/***************************************************************/
+TrigInfo *
+NewTrigInfo(char const *i)
+{
+    TrigInfo *ti = malloc(sizeof(TrigInfo));
+
+    if (!ti) {
+        return NULL;
+    }
+    ti->next = NULL;
+    ti->info = StrDup(i);
+    if (!ti->info) {
+        free(ti);
+        return NULL;
+    }
+    return ti;
+}
+
+/***************************************************************/
+/*                                                             */
+/*  FreeTrigInfo                                               */
+/*                                                             */
+/*  Free a TrigInfo objects.                                   */
+/*                                                             */
+/***************************************************************/
+void
+FreeTrigInfo(TrigInfo *ti)
+{
+    if (ti->info) {
+        free( (void *) ti->info);
+        ti->info = NULL;
+    }
+    ti->next = NULL;
+    free(ti);
+}
+
+void
+FreeTrigInfoChain(TrigInfo *ti)
+{
+    TrigInfo *next;
+
+    while(ti) {
+        next = ti->next;
+        FreeTrigInfo(ti);
+        ti = next;
+    }
+}
+
+/***************************************************************/
+/*                                                             */
+/*  AppendTrigInfo                                             */
+/*                                                             */
+/*  Append an info item to a trigger.                          */
+/*                                                             */
+/***************************************************************/
+int
+AppendTrigInfo(Trigger *t, char const *info)
+{
+    TrigInfo *ti;
+    TrigInfo *last;
+
+    if (!TrigInfoIsValid(info)) {
+        Eprint("%s", tr("Invalid INFO string: Must be of the form \"Header: Value\""));
+        return E_PARSE_ERR;
+    }
+
+    ti = NewTrigInfo(info);
+    last = t->infos;
+    if (!ti) {
+        return E_NO_MEM;
+    }
+    if (!last) {
+        t->infos = ti;
+        return OK;
+    }
+    if (TrigInfoHeadersAreTheSame(info, last->info)) {
+        Eprint("%s", tr("Duplicate INFO headers are not permitted"));
+        FreeTrigInfo(ti);
+        return E_PARSE_ERR;
+    }
+    while (last->next) {
+        last = last->next;
+        if (TrigInfoHeadersAreTheSame(info, last->info)) {
+            Eprint("%s", tr("Duplicate INFO headers are not permitted"));
+            FreeTrigInfo(ti);
+            return E_PARSE_ERR;
+        }
+    }
+    last->next = ti;
+    return OK;
+}
+
+int
+TrigInfoHeadersAreTheSame(char const *i1, char const *i2)
+{
+    char const *c1 = strchr(i1, ':');
+    char const *c2 = strchr(i2, ':');
+    if (!c1 || !c2) return 1;
+    if (c1 - i1 != c2 - i2) return 0;
+    if (!strncasecmp(i1, i2, (c1 - i1))) return 1;
+    return 0;
+}
+
+int
+TrigInfoIsValid(char const *info)
+{
+    char const *t;
+    char const *s = strchr(info, ':');
+    if (!s) return 0;
+    if (s == info) return 0;
+
+    t = info;
+    while (t < s) {
+        if (isspace(*t) || iscntrl(*t)) return 0;
+        t++;
+    }
+    return 1;
+}
+
+char const *
+FindTrigInfo(Trigger *t, char const *header)
+{
+    TrigInfo *ti;
+    size_t len;
+    char const *s;
+
+    if (!t || !header || !*header) return NULL;
+
+    ti = t->infos;
+    len = strlen(header);
+    while(ti) {
+        if (!strncasecmp(ti->info, header, len) &&
+            ti->info[len] == ':') {
+            s = ti->info + len + 1;
+            while(isspace(*s)) s++;
+            return s;
+        }
+        ti = ti->next;
+    }
+    return NULL;
+}
