@@ -107,6 +107,11 @@ typedef struct var {
     Value v;
 } Var;
 
+typedef struct triginfo {
+    struct triginfo *next;
+    char const *info;
+} TrigInfo;
+
 /* A trigger */
 typedef struct {
     int expired;
@@ -138,6 +143,7 @@ typedef struct {
     char omitfunc[VAR_NAME_LEN+1]; /* OMITFUNC function */
     DynamicBuffer tags;
     char passthru[PASSTHRU_LEN+1];
+    TrigInfo *infos;
 } Trigger;
 
 /* A time trigger */
@@ -200,14 +206,15 @@ typedef Parser *ParsePtr;  /* Pointer to parser structure */
 #define NO_MAX 127
 
 /* DEFINES for debugging flags */
-#define DB_PRTLINE      0x01
-#define DB_PRTEXPR      0x02
-#define DB_PRTTRIG      0x04
-#define DB_DUMP_VARS    0x08
-#define DB_ECHO_LINE    0x10
-#define DB_TRACE_FILES  0x20
-#define DB_PARSE_EXPR   0x40
-#define DB_HASHSTATS    0x80
+#define DB_PRTLINE      0x001
+#define DB_PRTEXPR      0x002
+#define DB_PRTTRIG      0x004
+#define DB_DUMP_VARS    0x008
+#define DB_ECHO_LINE    0x010
+#define DB_TRACE_FILES  0x020
+#define DB_PARSE_EXPR   0x040
+#define DB_HASHSTATS    0x080
+#define DB_TRANSLATE    0x100
 
 /* Enumeration of the tokens */
 enum TokTypes
@@ -216,9 +223,9 @@ enum TokTypes
   T_Date, T_DateTime, T_Day, T_Debug, T_Delta, T_Dumpvars, T_Duration,
   T_Else, T_Empty, T_EndIf, T_ErrMsg, T_Exit, T_Expr,
   T_Flush, T_Frename, T_Fset, T_Funset, T_If, T_IfTrig, T_In,
-  T_Include, T_IncludeCmd, T_IncludeR, T_IncludeSys, T_LastBack, T_LongTime,
-  T_MaybeUncomputable, T_Month, T_NoQueue, T_Number, T_Omit, T_OmitFunc,
-  T_Once, T_Ordinal, T_Pop, T_Preserve, T_Priority, T_Push,T_Rem,
+  T_Include, T_IncludeCmd, T_IncludeR, T_IncludeSys, T_Info, T_LastBack,
+  T_LongTime, T_MaybeUncomputable, T_Month, T_NoQueue, T_Number, T_Omit,
+  T_OmitFunc, T_Once, T_Ordinal, T_Pop, T_Preserve, T_Priority, T_Push,T_Rem,
   T_RemType, T_Rep, T_Scanfrom, T_Sched, T_Set, T_Skip, T_Tag, T_Through,
   T_Time, T_Translate, T_UnSet, T_Until, T_Warn, T_WkDay, T_Year
 };
